/*
 * Operation invocation.
 *
 * Copyright (C) 2019, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>
#include <string.h>

#include "ops.h"



/* Operations exposed by the program. */

extern struct operation operations[];



/* Produce a general result condition from the invocation of an operation. */

int handle_op_result(const char *operation, enum op_results op_result)
{
    if (op_result == OP_UNKNOWN)
    {
        fprintf(stderr, "Operation not recognised: %s\n", operation);
        return 1;
    }
    else if (op_result == OP_FAILED)
    {
        fprintf(stderr, "Operation failed: %s\n", operation);
        return 1;
    }
    else
        return 0;
}

/* Invocation of operations. */

enum op_results run_operation(const char *operation, int argc, char *argv[])
{
    struct operation *op;
    int exitcode;

    for (op = &operations[0]; op->name != NULL; op++)
    {
        if (!strcmp(operation, op->name))
        {
            exitcode = op->fn(argc, argv);
            if (exitcode)
                return OP_FAILED;
            break;
        }
    }

    if (op->name == NULL)
        return OP_UNKNOWN;

    return OP_SUCCESS;
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
